.. image:: geocompy_logo.png
   :width: 600
   :align: center
   :alt: GeoComPy logo

|
|
|

*****************************************
Welcome to the **GeoComPy** documentation
*****************************************

The GeoComPy package provides Python wrapper functions for controlling
various surveying instruments in automated tasks.

Links
=====

- :si-icon:`material/text-box-multiple` `Documentation <https://geocompy.readthedocs.io>`_
- :si-icon:`material/download` `Download <https://pypi.org/project/geocompy/>`_
- :si-icon:`material/github` `GitHub <https://github.com/MrClock8163/GeoComPy>`_

Legend
======

The documentation pages use various icons to show certain properties.
Below is a list of what each of them indicate.

- Protocols

  - :si-icon:`protocol_geocom` GeoCom
  - :si-icon:`protocol_gsionline` GSI Online

- Definitions

  - :si-icon:`material/alpha-c-box` Class
  - :si-icon:`material/alpha-m-box` Method
  - :si-icon:`material/alpha-a-box` Attribute
  - :si-icon:`material/alpha-f-box` Function
  - :si-icon:`material/alpha-p-box` Property
  - :si-icon:`material/alpha-v-box` Variable

Content
=======

.. toctree::
   :maxdepth: 1

   overview
   introduction
   connections
   changelog

.. toctree::
   :maxdepth: 1
   :caption: External references

   Instrumentman package <https://instrumentman.readthedocs.io>

.. toctree::
   :maxdepth: 1
   :caption: API documentation

   api/index
   api/data
   api/communication
   api/gsi/index
   api/gsi/dna/index
   api/geo/index

Indices

* :ref:`genindex`
* :ref:`modindex`
